@@ -21,8 +21,8 @@
 
 int main()
 {
-    typedef boost::geometry::model::d2::point_xy<double> point_type;
-    typedef boost::geometry::model::polygon<point_type> polygon_type;
+    using point_type = boost::geometry::model::d2::point_xy<double>;
+    using polygon_type = boost::geometry::model::polygon<point_type>;
 
     polygon_type poly;
     boost::geometry::read_wkt("POLYGON((0 0,0 10,10 10,10 0,0 0),(0 0,9 1,9 2,0 0),(0 0,2 9,1 9,0 0),(2 9,9 2,9 9,2 9))", poly);
